import React from 'react';

/**
 * @desc 实现类似v-if指令的组件
 * @example
 * <ComIf
        if={ view }
        then={ EditComponent }
        else={ SaveComponent }
    />
 */
class ComIf extends React.Component {
  getConditionComponent(conditionComponent) {
    const avoidUndfinedComponent = com => (com == null ? null : com);
    return typeof conditionComponent === 'function'
      ? avoidUndfinedComponent(conditionComponent())
      : conditionComponent;
  }

  render() {
    const {
      if: vif = false,
      then = null,
      else: nelse = null,
      children = null,
      ...others
    } = this.props;
    const getConditionComponent = this.getConditionComponent;

    if (children) {
      // const childrenWithProps = React.Children.map(children, child =>
      // 	React.cloneElement(child, { ...others })
      // );
      return vif ? children : null;
    }

    return vif ? getConditionComponent(then) : getConditionComponent(nelse);
  }
}
export default ComIf;
